pub struct ArenaConfig {
pub drop_items: bool,
}Expand description
Config builder for the arena
Fields
drop_items: boolWhether Drop::drop will be called on all items when the arena is dropped.
Defaults to true.
Implementations
Sourceimpl ArenaConfig
impl ArenaConfig
Sourcepub fn drop_items(self, drop_items: bool) -> Self
pub fn drop_items(self, drop_items: bool) -> Self
Whether Drop::drop will be called on all items when the arena is dropped.
Defaults to true.